/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package javax.enterprise.inject.spi;

/**
 * Fires event before registering bean with container.
 * 
 * @version $Rev: 815435 $ $Date: 2009-09-15 21:18:44 +0300 (Tue, 15 Sep 2009) $
 *
 * @param <X> bean class
 */
public interface ProcessBean<X>
{
    /**
     * Returns annotated.
     * 
     * @return annotated
     */
    public Annotated getAnnotated();
    
    /**
     * Returns bean instance.
     * 
     * @return bean
     */
    public Bean<X> getBean();

    /**
     * Aborts processing.
     * 
     * @param t throwable
     */
    public void addDefinitionError(Throwable t);

}